@@ -9,7 +9,7 @@ use Perl::Tidy;
 use Data::Dumper;
 use Module::Starter;
 $Data::Dumper::Deparse = 1;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our %CLASS;
 our $SUB_INDEX = 1;
 
@@ -255,7 +255,8 @@ sub _build_phase {
 	for (qw/BEGIN UNITCHECK CHECK INIT END/) {
 		if ($phases->{$_}) {
 			my $code = ref $phases->{$_} ? Dumper $phases->{$_} : $phases->{$_};
-			$code =~ s/\$VAR1 = sub //;
+			$code =~ s/\$VAR1 = //;
+			$code =~ s/sub\s*//;
 			$code =~ s/};$/}/;
 			$code = sprintf "%s %s;", 'BEGIN', $code;
 			push @codes, $code;
@@ -274,7 +275,8 @@ sub _build_subs {
 		my $code;
 		if ($class->{SUBS}{$sub}{CODE}) {
 			$code = ref $class->{SUBS}{$sub}{CODE} ? Dumper $class->{SUBS}{$sub}{CODE} : $class->{SUBS}{$sub}{CODE};
-			$code =~ s/\$VAR1 = sub //;
+			$code =~ s/\$VAR1 = //;
+			$code =~ s/sub\s*//;
 			$code =~ s/\s*\n*\s*package Module\:\:Generate\;|use warnings\;|use strict\;//g;
 			$code =~ s/{\s*\n*/{/;
 			$code =~ s/};$/}/;
@@ -448,7 +450,7 @@ Module::Generate - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
